@@ -1,11 +1,12 @@
 import collections
+import threading
 import time
 import traceback
 from typing import List, Union
 
 import httpx
 
-from botoy import json, macro
+from botoy import macro
 from botoy.config import Config
 from botoy.log import logger
 
@@ -20,6 +21,7 @@ class Action:
             base_url=self.config.address,
             params={'qq': self.qq, 'timeout': timeout},
         )
+        self.lock = threading.Lock()
 
     ############发送相关############
     def sendFriendText(self, user: int, content: str) -> dict:
@@ -344,6 +346,36 @@ class Action:
             },
         )
 
+    def getVideoURL(self, group: int, videoMD5: str, videoURL: str) -> dict:
+        """获取视频链接
+        :param group: 群号
+        :param videoMD5: 视频的 MD5 值，可以从上报的消息中获得
+        :param videoURL: 上报的消息中传给的 url 值
+        """
+        return self.post(
+            'PttCenterSvr.ShortVideoDownReq',
+            {"GroupID": group, "VideoUrl": videoURL, "VideoMd5": videoMD5},
+        )
+
+    def getFriendFileURL(self, fileID: str) -> dict:
+        """获取好友文件链接
+        :param fileID: 文件 ID，可由上报的消息中获得
+        """
+        return self.post(
+            'OfflineFilleHandleSvr.pb_ftn_CMD_REQ_APPLY_DOWNLOAD-1200',
+            {"FileID": fileID},
+        )
+
+    def getGroupFileURL(self, group: int, fileID: str) -> dict:
+        """获取好友文件链接
+        :param group: 群号
+        :param fileID: 文件 ID，可由上报的消息中获得
+        """
+        return self.post(
+            'OidbSvc.0x6d6_2',
+            {'GroupID': group, "FileID": fileID},
+        )
+
     def repostVideo2Friend(self, user: int, forwordBuf: str) -> dict:
         """转发视频到好友
         :param user: 好友QQ
@@ -369,19 +401,37 @@ class Action:
         """获取任意用户信息昵称头像等"""
         return self.post('GetUserInfo', {'UserID': user})
 
-    def getUserList(self) -> List[dict]:  # FIXME: 目前只适用于好友较少一次获取就可以的情况，好友较多需要循环获取
+    def getUserList(self) -> List[dict]:
         """获取好友列表"""
-        data = self.post('GetQQUserList', {'StartIndex': 0})
-        if 'Friendlist' in data:
-            return data['Friendlist']
-        return []
+        friend_list = []
+        start_index = 0
+        while True:
+            data = self.post('GetQQUserList', {'StartIndex': start_index})
+            if 'Friendlist' not in data:
+                break
+            friend_list.extend(data['Friendlist'])
+            if len(friend_list) >= int(data.get('Totoal_friend_count', 0)):  # 这里有个拼写错误
+                break
+            if "GetfriendCount" not in data:
+                break
+            start_index += int(
+                data.get("GetfriendCount", 999999)
+            )  # 设置 999999 为了在 API 坏了的情况下能跳出循环
+        return friend_list
 
-    def getGroupList(self) -> List[dict]:  # FIXME: 循环获取
+    def getGroupList(self) -> List[dict]:
         """获取群列表"""
-        data = self.post('GetGroupList', {'NextToken': ''})
-        if 'TroopList' in data:
-            return data['TroopList']
-        return []
+        next_token = ""
+        group_list = []
+        while True:
+            data = self.post('GetGroupList', {'NextToken': next_token})
+            if 'TroopList' not in data:
+                break
+            group_list.extend(data['TroopList'])
+            next_token = data.get('NextToken', '')
+            if not next_token:
+                break
+        return group_list
 
     def getGroupMembers(self, group: int) -> List[dict]:
         """获取群成员列表"""
@@ -584,6 +634,8 @@ class Action:
 
         # 发送请求
         try:
+            self.lock.acquire()
+            threading.Timer(1, self.release_lock).start()
             resp = self.c.request(
                 method, httpx.URL(url=path, params=params), json=payload
             )
@@ -602,7 +654,7 @@ class Action:
         # 处理数据
         try:
             data = resp.json()
-        except json.JSONDecodeError as e:
+        except Exception as e:
             logger.error('API响应结果非json格式')
             return {}
 
@@ -650,3 +702,6 @@ class Action:
     ) -> dict:
         """封装get操作"""
         return self.baseRequest('GET', funcname=funcname, path=path, params=params)
+
+    def release_lock(self):
+        self.lock.release()
