@@ -1,3 +1,5 @@
+import asyncio
+import importlib
 import json
 import os
 import pathlib
@@ -6,6 +8,9 @@ import textwrap
 
 import click
 
+from .__version__ import __version__
+from .async_client import AsyncBotoy
+from .client import Botoy
 from .util import check_schema
 
 echo = click.echo
@@ -36,9 +41,18 @@ def cli():
     $ botoy add -n test -f -g
 
     可选项为-f -g -e 分别代表是否包含处理好友，群，事件，如果都不传，表示都要！
+
+    3. 启动机器人(要求入口文件名为bot.py)
+    $ botoy run
     """
 
 
+@cli.command()
+def version():
+    """版本号"""
+    echo(__version__)
+
+
 @cli.command()
 @click.option('-n', '--name', prompt="程序入口文件名", default='bot', show_default=True)
 @click.option('-q', '--qq', prompt="机器人qq号", type=int, required=True)
@@ -126,7 +140,7 @@ def init(name, qq, host, port):
 @click.option('-e', '--event', is_flag=True, help='是否要接收事件消息?')
 def add(name, friend, group, event):
     """创建插件"""
-    here = pathlib.Path('.').parent
+    here = pathlib.Path('.').absolute()
     if here.name != 'plugins':
         if not os.path.isdir('plugins'):
             sys.exit('插件目录plugins不存在')
@@ -179,5 +193,31 @@ def add(name, friend, group, event):
     echo('ok')
 
 
+@cli.command()
+def run():
+    """启动机器人
+    要求入口文件名为bot.py
+    """
+    # look for bot.py
+    if not pathlib.Path('bot.py').exists():
+        sys.exit('该命令只接受入口文件命名为bot.py')
+    # look for Botoy client
+    sys.path.append(str(pathlib.Path('.').absolute()))
+    module = importlib.import_module('bot')
+    client = None
+    for item in module.__dict__.values():
+        if isinstance(item, (Botoy, AsyncBotoy)):
+            client = item
+            break
+    else:
+        sys.exit('无法找到(Async)Botoy对象')
+    if client is not None:
+        # 先判断子类
+        if isinstance(client, AsyncBotoy):
+            asyncio.run(client.run())
+        else:
+            client.run()
+
+
 if __name__ == "__main__":
     cli()
