@@ -44,7 +44,7 @@ class Config:
                 _c = json.load(f)
         except FileNotFoundError:
             pass
-        except json.JSONDecodeError as e:
+        except Exception as e:
             raise InvalidConfigError('配置文件不规范') from e
 
         # host
@@ -54,6 +54,7 @@ class Config:
                 self.host = 'http://127.0.0.1'
             else:
                 self.host = check_schema(host)
+        self.host = self.host.strip('/')  # 防止手动设置host，末尾是/符号，而报错
 
         # port
         if self.port is None:
